%% O2 Stochastic anisotropic analysis figures
% 

%% Figure 1 -- Broadband radiometer
% SNR on top row, 95% upper limits on GW flux on bottom
% row [ergs cm^-2 s^-1 Hz^-1]

alphas = [0, 2, 3];
for alpha=alphas
        SNR = textread(['figure1_BBR_alpha' num2str(alpha) '_SNR_map_data.txt']);
        plotMapAitoff(SNR, 360, 181, -1);
        colorbar('FontSize',25);
        set(gcf,'renderer', 'zbuffer');
        set(gca, 'position', [0.12 0.2 .76 1]);
        print('-dpng',['figure1_BBR_alpha' num2str(alpha) '_snr_map.png']);
end

% Upper limit on bottom row
 
for alpha=alphas
        flux_ul = textread(['figure1_BBR_alpha' num2str(alpha) '_UL_map_data.txt']);
        plotMapAitoff(flux_ul, 360, 181, -1);
        colorbar('FontSize',25);
        set(gcf,'renderer', 'zbuffer');
        set(gca, 'position', [0.1 0.15 .7 1]);
        print('-dpng',['figure1_BBR_alpha' num2str(alpha) '_UL_map.png']);
end


%% Figure 2 -- SHD results
% SNR on top row, 95% upper limits on dimensionless energy density
% on the bottom row [sr^-1].
for alpha=alphas
        SNR = textread(['figure2_SHD_alpha' num2str(alpha) '_SNR_map_data.txt']);
        plotMapAitoff(SNR, 360, 181, -1);
        colorbar('FontSize',25);
        set(gcf,'renderer', 'zbuffer');
        set(gca, 'position', [0.12 0.2 .76 1]);
        print('-dpng',['figure2_SHD_alpha' num2str(alpha) '_snr_map.png']);
end

% Upper limit on bottom row
 
for alpha=alphas
        flux_ul = textread(['figure2_SHD_alpha' num2str(alpha) '_UL_map_data.txt']);
        plotMapAitoff(flux_ul, 360, 181, -1);
        colorbar('FontSize',25);
        set(gcf,'renderer', 'zbuffer');
        set(gca, 'position', [0.1 0.15 .7 1]);
        print('-dpng',['figure2_SHD_alpha' num2str(alpha) '_UL_map.png']);
end

%% Figure 3 -- $C_{\ell}$ upper limits
% Upper limits on $C_{\ell}$'s at 95% confidence level for 
% the SHD analyses [sr^-1].

colors = {'k','r','b'};
markers ={'v','o','s'};
figure('units','normalized','position',[0 0 1 0.6])
for ii=1:length(alphas)
    M = csvread(['figure3_cl_alpha' num2str(alphas(ii)) '_line_data.txt']);
    scatter(M(:, 1), M(:, 2), 128, colors{ii}, markers{ii}, 'MarkerFaceColor', colors{ii});
    hold on;
end
ylim([1e-10 3e-8]);
xlim([-0.5 16.5]);
set(gca,'YScale', 'log');
grid on;
pretty;
xlabel('$l$', 'Interpreter','latex','FontSize',36);
ylabel('$C_l^{1/2}$ [sr$^{-1}$]', 'Interpreter','latex','FontSize',36);
legend({'$\alpha$=0','$\alpha$=2/3', '$\alpha$=3'}, 'Interpreter', 'latex', 'FontSize', 28);
print('-dpng', ['figure3_cl_uls_all.png'], '-r0');

%% Figure 4 -- Narrowband radiometer
% 95% upper limits on strain amplitude, $h_0$, in
% three directions.

names = {'scox1','gc','sn'};
titles = {'Sco X-1', 'Galactic Center', 'SN 1987a'};
for ii = 1:length(names)
        figure('units','normalized','position',[0 0 0.7 0.7]);
        M = csvread(['figure4_' names{ii} '_nbr_spectrum.txt']);
        loglog(M(:, 1), M(:, 2), 'Color', [0.3 0.3 0.3], 'LineWidth', 1.5);
        hold on;
        loglog(M(:, 1), M(:, 3), 'k', 'LineWidth', 1.2);
        pretty;
        grid minor;
        xlabel('Frequency [Hz]', 'Interpreter','latex');
        ylabel('Strain amplitude ($h_0$)', 'Interpreter' ,'latex');
        legend({['O1+O2 ' num2str(0.95*100) '$\%$ UL'], '1$\sigma$ sensitivity'}, 'Interpreter', 'latex', 'FontSize', 28);
        xl = get(gca,'XLabel');
        xAX = get(gca,'XAxis');
        set(xAX,'FontSize', 26);
        set(xl, 'FontSize', 28);
        yl = get(gca,'YLabel');
        yAX = get(gca,'YAxis');
        set(yAX,'FontSize', 26)
        set(yl, 'FontSize', 28);
        xlim([min(M(:, 1)),max(M(:, 1))]);
        title(titles{ii}, 'Interpreter','latex');
        print('-dpng', ['figure4_' names{ii} '_ul_spectrum']);
end

%% Figure 5 -- Outlier cumulative SNR
% Cumulative SNR vs. time for outlier frequency bin
% at 36.0625 Hz. Without O1 data, the final SNR is 5.3.
% including the O1 data results in a final SNR of 4.8.

M = csvread(['figure5_snr_vs_time.txt']);
obsTime = M(:,1);
Y_cumulative = M(:,2);
sigma_cumulative = M(:,3);
O1_obstime = M(1, 4); % saved with each line in file but only one value

figure('units','normalized','position', [0 0 1 0.7]);
scatter(obsTime, Y_cumulative ./ sigma_cumulative, 'k', 'MarkerFaceColor','b');
hold on;
xlabel('Observation Time (days)', 'FontSize', 24, 'Interpreter', 'latex');
ylabel('Cumulative SNR', 'FontSize', 24, 'Interpreter', 'latex');
plot([O1_obstime O1_obstime], [-6, 6], 'k');
text(O1_obstime - 14,3.5,'$\longleftarrow {\rm O1}$','FontSize', 25, 'Interpreter','latex')
text(O1_obstime + 2,3.5,'${\rm O2} \longrightarrow$', 'FontSize',25, 'Interpreter','latex')
xAX = get(gca,'XAxis');
set(xAX,'FontSize', 20);
yAX = get(gca,'YAxis');
set(yAX,'FontSize', 20)
xlim([-5, 130]);
grid on;
ylim([-6, 6]);
print('-dpng', 'figure5_snr_vs_time.png');

